(request-to-message {:keys [query-string] :as req})Maps the ring request map to the format of the airbrake params
Maps the ring request map to the format of the airbrake params
(wrap-airbrake handler airbrake-config)(wrap-airbrake handler airbrake-config request-mapper)Catches exceptions and sends Airbrake notification.
Catches exceptions and sends Airbrake notification.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |